@@ -30,7 +30,7 @@ BEGIN {
     Readonly $MAX_CONFIDENCE_DEFAULT => 95;
     Readonly $MIN_CONFIDENCE_DEFAULT => 50;
 }
-our $VERSION = '2.10.0';
+our $VERSION = '2.10.2';
 
 use Glib::Object::Subclass GooCanvas2::Canvas::, signals => {
     'zoom-changed' => {
@@ -430,7 +430,7 @@ sub add_box {
         my $y = $selection->{y} + $selection->{height} / 2;
         $parent = $self->get_item_at( $x, $y, FALSE );
         while ( defined $parent
-            and not $parent->isa('Gscan2pdf::Canvas::Bbox') )
+            and ( not defined $parent->{type} or $parent->{type} eq 'word' ) )
         {
             $parent = $parent->get_property('parent');
         }
@@ -447,7 +447,7 @@ sub add_box {
         bbox           => $selection,
         transformation => \@transformation,
     );
-    if ( defined $text and $text ne q{} ) { $options2{text} = $text }
+    if ( length $text ) { $options2{text} = $text }
 
     # copy parameters from box from OCR output
     for my $key (qw(baseline confidence id text textangle type)) {
@@ -463,8 +463,7 @@ sub add_box {
 
     my $bbox = Gscan2pdf::Canvas::Bbox->new(%options2);
 
-    if ($text) {
-
+    if ( defined $bbox and length $text ) {
         $self->add_box_to_index($bbox);
 
         # clicking text box produces a dialog to edit the text
@@ -604,6 +603,11 @@ sub confidence_binary_search {
 
 sub add_box_to_index {
     my ( $self, $bbox ) = @_;
+    if ( not defined $bbox ) {
+        Glib->warning( __PACKAGE__,
+            'Attempted to add undefined box to confidence list' );
+        return;
+    }
     my $confidence = $bbox->get('confidence');
     if ( not @{ $self->{confidence_list} } ) {
         push @{ $self->{confidence_list} }, [ $bbox, $confidence ];
@@ -616,6 +620,11 @@ sub add_box_to_index {
 
 sub remove_current_box_from_index {
     my ($self) = @_;
+    if ( not defined $self->{confidence_index} ) {
+        Glib->warning( __PACKAGE__,
+            'Attempted to delete undefined index from confidence list' );
+        return;
+    }
     splice @{ $self->{confidence_list} }, $self->{confidence_index}, 1;
     if ( $self->{confidence_index} > $#{ $self->{confidence_list} } ) {
         $self->{confidence_index} = $#{ $self->{confidence_list} };
