@@ -25,7 +25,7 @@ BEGIN {
     $EMPTY = q{};
 }
 my $SPACE = q{ };
-our $VERSION = '2.10.0';
+our $VERSION = '2.10.2';
 
 use Glib::Object::Subclass GooCanvas2::CanvasGroup::, signals => {
     'text-changed' => {
@@ -137,7 +137,7 @@ sub new {
     #        'stroke-color' => 'orange' );
     #}
 
-    if ( $self->{text} ) {
+    if ( defined $self->{text} and $self->{text} ne q{} ) {
 
         # create text and then scale, shift & rotate it into the bounding box
         my $text = GooCanvas2::CanvasText->new(
@@ -310,7 +310,7 @@ sub transform_text {
     my $text        = $self->get('text');
     $angle ||= 0;
 
-    if ( $bbox && $text ) {
+    if ( $bbox and length $text ) {
         my ( $x, $y, $width, $height ) =
           ( $bbox->{x}, $bbox->{y}, $bbox->{width}, $bbox->{height} );
         my ( $x2, $y2 ) = ( $x + $width, $y + $height );
@@ -342,6 +342,7 @@ sub update_box {
 
     my $text_w = $self->get_text_widget;
     if ( length $text ) {
+        my $old_conf = $self->get('confidence');
         $text_w->set( text => $text );
         $self->set( text       => $text );
         $self->set( confidence => $_100_PERCENT );
@@ -362,9 +363,11 @@ sub update_box {
             $self->transform_text( $scale, $textangle );
         }
 
-        my $canvas = $self->get_canvas;
-        $canvas->remove_current_box_from_index;
-        $canvas->add_box_to_index($self);
+        if ( $old_conf != $self->get('confidence') ) {
+            my $canvas = $self->get_canvas;
+            $canvas->remove_current_box_from_index;
+            $canvas->add_box_to_index($self);
+        }
     }
     else {
         $self->delete_box;
@@ -448,7 +451,7 @@ sub to_hocr {
           . "<$tag class='$type' "
           . join( $SPACE, $id, $title ) . '>'
           . (
-            $self->{text}
+            ( defined $self->{text} and $self->{text} ne q{} )
             ? HTML::Entities::encode( $self->{text}, "<>&\"'" )
             : "\n"
           );
